aboutsummaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2023-06-04 14:10:54 +0200
committerChristian Grothoff <christian@grothoff.org>2023-06-04 14:10:54 +0200
commit0ad3de938e37cd4f34dd791283350ccfc09df2db (patch)
tree8c8fc14d341a5e4d78e39c5c09c9d35fbf261355 /src/include
parent809300158caaa0215c36ef89c7e38f0edfa93593 (diff)
downloadexchange-0ad3de938e37cd4f34dd791283350ccfc09df2db.tar.xz
address API stability FIXMEs in taler_exchange_service
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_exchange_service.h119
1 files changed, 96 insertions, 23 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 5fcfa4038..c6c1d3a13 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -4548,7 +4548,7 @@ struct TALER_EXCHANGE_ManagementPostExtensionsHandle *
TALER_EXCHANGE_management_post_extensions (
struct GNUNET_CURL_Context *ctx,
const char *url,
- struct TALER_EXCHANGE_ManagementPostExtensionsData *ped,
+ const struct TALER_EXCHANGE_ManagementPostExtensionsData *ped,
TALER_EXCHANGE_ManagementPostExtensionsCallback cb,
void *cb_cls);
@@ -5091,7 +5091,7 @@ TALER_EXCHANGE_lookup_aml_decision (
/**
- * Cancel #TALER_EXCHANGE_add_aml_decision() operation.
+ * Cancel #TALER_EXCHANGE_lookup_aml_decision() operation.
*
* @param rh handle of the operation to cancel
*/
@@ -5105,18 +5105,30 @@ TALER_EXCHANGE_lookup_aml_decision_cancel (
*/
struct TALER_EXCHANGE_AddAmlDecision;
+
+/**
+ * Response when making an AML decision.
+ */
+struct TALER_EXCHANGE_AddAmlDecisionResponse
+{
+ /**
+ * HTTP response data.
+ */
+ struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+
/**
* Function called with information about storing an
* an AML decision.
*
* @param cls closure
* @param hr HTTP response data
*/
-// FIXME: bad API
typedef void
(*TALER_EXCHANGE_AddAmlDecisionCallback) (
void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr);
+ const struct TALER_EXCHANGE_AddAmlDecisionResponse *adr);
/**
* Inform the exchange that an AML decision has been taken.
@@ -5162,17 +5174,27 @@ TALER_EXCHANGE_add_aml_decision_cancel (
/**
+ * Response when adding a partner exchange.
+ */
+struct TALER_EXCHANGE_ManagementAddPartnerResponse
+{
+ /**
+ * HTTP response data.
+ */
+ struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+/**
* Function called with information about the change to
* an AML officer status.
*
* @param cls closure
* @param hr HTTP response data
*/
-// FIXME: bad API
typedef void
(*TALER_EXCHANGE_ManagementAddPartnerCallback) (
void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr);
+ const struct TALER_EXCHANGE_ManagementAddPartnerResponse *apr);
/**
@@ -5224,16 +5246,26 @@ TALER_EXCHANGE_management_add_partner_cancel (
/**
+ * Response when enabling an auditor.
+ */
+struct TALER_EXCHANGE_ManagementAuditorEnableResponse
+{
+ /**
+ * HTTP response data.
+ */
+ struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+/**
* Function called with information about the auditor setup operation result.
*
* @param cls closure
* @param hr HTTP response data
*/
-// FIXME: bad API
typedef void
(*TALER_EXCHANGE_ManagementAuditorEnableCallback) (
void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr);
+ const struct TALER_EXCHANGE_ManagementAuditorEnableResponse *aer);
/**
@@ -5278,18 +5310,27 @@ void
TALER_EXCHANGE_management_enable_auditor_cancel (
struct TALER_EXCHANGE_ManagementAuditorEnableHandle *ah);
+/**
+ * Response when disabling an auditor.
+ */
+struct TALER_EXCHANGE_ManagementAuditorDisableResponse
+{
+ /**
+ * HTTP response data.
+ */
+ struct TALER_EXCHANGE_HttpResponse hr;
+};
/**
* Function called with information about the auditor disable operation result.
*
* @param cls closure
* @param hr HTTP response data
*/
-// FIXME: bad API
typedef void
(*TALER_EXCHANGE_ManagementAuditorDisableCallback) (
void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr);
+ const struct TALER_EXCHANGE_ManagementAuditorDisableResponse *adr);
/**
@@ -5468,16 +5509,26 @@ TALER_EXCHANGE_management_disable_wire_cancel (
/**
+ * Response when setting wire fees.
+ */
+struct TALER_EXCHANGE_ManagementSetWireFeeResponse
+{
+ /**
+ * HTTP response data.
+ */
+ struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+/**
* Function called with information about the wire enable operation result.
*
* @param cls closure
* @param hr HTTP response data
*/
-// FIXME: bad API
typedef void
(*TALER_EXCHANGE_ManagementSetWireFeeCallback) (
void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr);
+ const struct TALER_EXCHANGE_ManagementSetWireFeeResponse *wfr);
/**
@@ -5525,16 +5576,27 @@ TALER_EXCHANGE_management_set_wire_fees_cancel (
/**
+ * Response when setting global fees.
+ */
+struct TALER_EXCHANGE_ManagementSetGlobalFeeResponse
+{
+ /**
+ * HTTP response data.
+ */
+ struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+
+/**
* Function called with information about the global fee setting operation result.
*
* @param cls closure
* @param hr HTTP response data
*/
-// FIXME: bad API
typedef void
(*TALER_EXCHANGE_ManagementSetGlobalFeeCallback) (
void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr);
+ const struct TALER_EXCHANGE_ManagementSetGlobalFeeResponse *gfr);
/**
@@ -5586,17 +5648,28 @@ TALER_EXCHANGE_management_set_global_fees_cancel (
/**
+ * Response when adding denomination signature by auditor.
+ */
+struct TALER_EXCHANGE_AuditorAddDenominationResponse
+{
+ /**
+ * HTTP response data.
+ */
+ struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+
+/**
* Function called with information about the POST
* /auditor/$AUDITOR_PUB/$H_DENOM_PUB operation result.
*
* @param cls closure
* @param hr HTTP response data
*/
-// FIXME: bad API
typedef void
(*TALER_EXCHANGE_AuditorAddDenominationCallback) (
void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr);
+ const struct TALER_EXCHANGE_AuditorAddDenominationResponse *adr);
/**
@@ -5105,18 +5105,30 @@ TALER_EXCHANGE_lookup_aml_decision_cancel (
*
* @param cls closure
- * @param hr HTTP response data
+ * @param adr response data
*/
@@ -5162,17 +5174,27 @@ TALER_EXCHANGE_add_aml_decision_cancel (
*
* @param cls closure
- * @param hr HTTP response data
+ * @param apr response data
*/
@@ -5224,16 +5246,26 @@ TALER_EXCHANGE_management_add_partner_cancel (
*
* @param cls closure
- * @param hr HTTP response data
+ * @param aer response data
*/
@@ -5278,18 +5310,27 @@ void
*
* @param cls closure
- * @param hr HTTP response data
+ * @param adr HTTP response data
*/
@@ -5468,16 +5509,26 @@ TALER_EXCHANGE_management_disable_wire_cancel (
*
* @param cls closure
- * @param hr HTTP response data
+ * @param wfr response data
*/
@@ -5525,16 +5576,27 @@ TALER_EXCHANGE_management_set_wire_fees_cancel (
*
* @param cls closure
- * @param hr HTTP response data
+ * @param gfr HTTP response data
*/
@@ -5586,17 +5648,28 @@ TALER_EXCHANGE_management_set_global_fees_cancel (
*
* @param cls closure
- * @param hr HTTP response data
+ * @param adr HTTP response data
*/